==> haskell-generic-data-1.1.0.0-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 generic-data
version:              1.1.0.0
visibility:           public
id:                   generic-data-1.1.0.0-Am72qjsOUZcDxGreq2iUOx
key:                  generic-data-1.1.0.0-Am72qjsOUZcDxGreq2iUOx
license:              MIT
copyright:            2018-2020 Li-yao Xia
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
homepage:             https://github.com/Lysxia/generic-data#readme
synopsis:             Deriving instances with GHC.Generics and related utilities
description:
    Generic implementations of standard type classes.
    Operations on generic representations to help using "GHC.Generics".
    See README.

category:             Generics
abi:                  aecbae1e4342146244c5baa0d1d36831
exposed:              True
exposed-modules:
    Generic.Data Generic.Data.Internal.Compat
    Generic.Data.Internal.Data Generic.Data.Internal.Enum
    Generic.Data.Internal.Error Generic.Data.Internal.Functions
    Generic.Data.Internal.Generically Generic.Data.Internal.Meta
    Generic.Data.Internal.Microsurgery Generic.Data.Internal.Newtype
    Generic.Data.Internal.Prelude Generic.Data.Internal.Read
    Generic.Data.Internal.Resolvers Generic.Data.Internal.Show
    Generic.Data.Internal.Traversable Generic.Data.Internal.Utils
    Generic.Data.Microsurgery Generic.Data.Orphans Generic.Data.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/generic-data-1.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/generic-data-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generic-data
hs-libraries:         HSgeneric-data-1.1.0.0-Am72qjsOUZcDxGreq2iUOx
depends:
    ap-normalize-0.1.0.1-GFtkhmtfhAfInZbxP9bPkJ base-4.16.4.0
    base-orphans-0.8.8.2-75FlsKP5UVdIbLopNxxJmB
    contravariant-1.5.5-6oWUjmJNxDBFhugVD5s9dq ghc-boot-th-9.2.8
    show-combinators-0.2.0.0-HrFsRmC05OF3XeBeLL5T7J

haddock-interfaces:
    /usr/share/doc/haskell-generic-data/html/generic-data.haddock

haddock-html:         /usr/share/doc/haskell-generic-data/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generic-data-1.1.0.0-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 generic-data
version:              1.1.0.0
visibility:           public
id:                   generic-data-1.1.0.0-HUCYAsQ73TeHBCh6oddBDX
key:                  generic-data-1.1.0.0-HUCYAsQ73TeHBCh6oddBDX
license:              MIT
copyright:            2018-2020 Li-yao Xia
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
homepage:             https://github.com/Lysxia/generic-data#readme
synopsis:             Deriving instances with GHC.Generics and related utilities
description:
    Generic implementations of standard type classes.
    Operations on generic representations to help using "GHC.Generics".
    See README.

category:             Generics
abi:                  6c4b91513a8232a8e04384a7f2868631
exposed:              True
exposed-modules:
    Generic.Data Generic.Data.Internal.Compat
    Generic.Data.Internal.Data Generic.Data.Internal.Enum
    Generic.Data.Internal.Error Generic.Data.Internal.Functions
    Generic.Data.Internal.Generically Generic.Data.Internal.Meta
    Generic.Data.Internal.Microsurgery Generic.Data.Internal.Newtype
    Generic.Data.Internal.Prelude Generic.Data.Internal.Read
    Generic.Data.Internal.Resolvers Generic.Data.Internal.Show
    Generic.Data.Internal.Traversable Generic.Data.Internal.Utils
    Generic.Data.Microsurgery Generic.Data.Orphans Generic.Data.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/generic-data-1.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/generic-data-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generic-data
hs-libraries:         HSgeneric-data-1.1.0.0-HUCYAsQ73TeHBCh6oddBDX
depends:
    ap-normalize-0.1.0.1-4jX3bSWMD45Pqqr6q5r7b base-4.16.4.0
    base-orphans-0.8.8.2-1HC3Bnsq2koLxGZ8ujZxkx
    contravariant-1.5.5-6oWUjmJNxDBFhugVD5s9dq ghc-boot-th-9.2.8
    show-combinators-0.2.0.0-HrFsRmC05OF3XeBeLL5T7J

haddock-interfaces:
    /usr/share/doc/haskell-generic-data/html/generic-data.haddock

haddock-html:         /usr/share/doc/haskell-generic-data/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
